@@ -3,6 +3,7 @@
 import ast
 import os
 import re
+import copy
 
 from apiautotest import exceptions, utils, validator
 from apiautotest.compat import basestring, builtin_str, numeric_types, str
@@ -14,6 +15,8 @@ variable_regex_compile = re.compile(r"\$\{(\w+)\}|\$(\w+)")
 # function notation, e.g. ${func1($var_1, $var_3)}
 function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\w\.\-/\s=,]*)\)\}")
 
+temp_extracted_set = set()
+
 
 def parse_string_value(str_value):
     """ parse string to number if possible
@@ -827,7 +830,7 @@ def _extend_with_api(test_dict, api_def_dict):
     # merge & override setup_hooks
     def_setup_hooks = api_def_dict.pop("setup_hooks", [])
     ref_setup_hooks = test_dict.get("setup_hooks", [])
-    extended_setup_hooks = def_setup_hooks + ref_setup_hooks
+    extended_setup_hooks = ref_setup_hooks + def_setup_hooks
     if extended_setup_hooks:
         test_dict["setup_hooks"] = extended_setup_hooks
     # merge & override teardown_hooks
@@ -870,6 +873,18 @@ def _extend_with_testcase(test_dict, testcase_def_dict):
         or testcase_def_dict["config"].pop("name", None) \
         or "testcase name undefined"
 
+    # merge & override setup_hooks and teardown_hooks
+    def_teardown_hooks = testcase_def_dict["config"].pop("teardown_hooks", [])
+    ref_teardown_hooks = test_dict.pop("teardown_hooks", [])
+    extended_teardown_hooks = def_teardown_hooks + ref_teardown_hooks
+    if extended_teardown_hooks:
+        testcase_def_dict["config"]["teardown_hooks"] = extended_teardown_hooks
+    def_setup_hooks = testcase_def_dict["config"].pop("setup_hooks", [])
+    ref_setup_hooks = test_dict.pop("setup_hooks", [])
+    extended_setup_hooks = ref_setup_hooks + def_setup_hooks
+    if extended_setup_hooks:
+        testcase_def_dict["config"]["setup_hooks"] = extended_setup_hooks
+
     # override testcase config name, output, etc.
     testcase_def_dict["config"].update(test_dict)
     testcase_def_dict["config"]["name"] = test_name
@@ -918,13 +933,14 @@ def __prepare_testcase_tests(tests, config, project_mapping, session_variables_s
         project_mapping (dict):
 
     """
+    global temp_extracted_set
     config_variables = config.get("variables", {})
     config_base_url = config.get("base_url", "")
     config_verify = config.get("verify", True)
     functions = project_mapping.get("functions", {})
 
     prepared_testcase_tests = []
-    session_variables_set = set(config_variables.keys()) | (session_variables_set or set())
+    session_variables_set = set(config_variables.keys()) | (session_variables_set or set()) | temp_extracted_set
     for test_dict in tests:
 
         teststep_variables_set = {"request", "response"}
@@ -980,10 +996,12 @@ def __prepare_testcase_tests(tests, config, project_mapping, session_variables_s
             test_dict["request"]["verify"] = config_verify
 
         # move extracted variable to session variables
-        if "extract" in test_dict:
+        if test_dict.get("extract", {}):
             extract_mapping = utils.ensure_mapping_format(test_dict["extract"])
             session_variables_set |= set(extract_mapping.keys())
+            temp_extracted_set |= session_variables_set
 
+        session_variables_set |= temp_extracted_set
         teststep_variables_set |= session_variables_set
 
         # convert validators to lazy function
